CompositeHandler

Struct CompositeHandler 

pub struct CompositeHandler { /* private fields */ }
A composite handler that delegates to specialized handlers based on effect type

Implementations

Source

impl CompositeHandler

pub fn new(device_id: DeviceId, execution_mode: ExecutionMode) -> Self

Create a new composite handler

pub fn for_testing(device_id: DeviceId) -> Self

Create a composite handler for testing

pub fn for_production(device_id: DeviceId) -> Self

Create a composite handler for production

pub fn for_simulation(device_id: DeviceId, seed: u64) -> Self

Create a composite handler for simulation

pub fn register_handler( &mut self, effect_type: EffectType, handler: Box<dyn Handler>, ) -> Result<(), CompositeError>

Register a handler for a specific effect type

pub fn register_all( &mut self, options: RegisterAllOptions, ) -> Result<(), RegistryError>

Register the default handler bundle.

Requires explicit opt-in for impure handlers via RegisterAllOptions.

pub fn unregister_handler( &mut self, effect_type: EffectType, ) -> Option<Box<dyn RegistrableHandler>>

Unregister a handler for a specific effect type

pub fn has_handler(&self, effect_type: EffectType) -> bool

Check if a handler is registered for an effect type

pub fn registered_effect_types(&self) -> Vec<EffectType>

Get all registered effect types

pub fn device_id(&self) -> DeviceId

Get the device ID